/************************************************
              Class Tree

This class define the Tree objects used within
the 15-111/200 Mastery Exam/Fall 2002

Students are not permitted to modify or augment
this class in any way. This file must not change.

You are not required to understand the implementation
of these methods. But, it will likely be useful
for you to understand what they can accomplish
for you.

Exam for 15-111/200  Fall 2002

*************************************************/

import java.util.*;

public class Snack implements Comparable
{
  // Properties of a snack
  private Vector ingredients; // List of ingredients, each is a String 
  private double priceInDollarsAndCents; // In dollars, cents as decimal
  private String tradeName; // The trade name of the snack

  /**
    * This is the constructor of a Snack
    * @ingredients is a Vector containing the list of ingredients, 
    * each of which is represented as a String, e.g "Peanut Butter"
    * @priceInDollarsAndCents is the selling price of the Snack,
    * represented in dollars, with cents to the right of the decimal
    */ 
  public Snack (String tradeName, Vector ingredients, 
                double priceInDollarsAndCents)
  {
    this.tradeName=tradeName;
    this.ingredients = ingredients;
    this.priceInDollarsAndCents = priceInDollarsAndCents;
  }


  /**
    * This returns the ingredients of the Snack, as a list of Strings stored
    * within a Vector.
    * @return the height of the Tree in whole feet.
    */ 
  public Vector getIngredients()
  {
    return ingredients;
  }


  /**
    * This is returns the selling price of the Snack
    * @return the selling price of the Snack in dollars, with cents as 
    * a fraction
    */ 
  public double getPriceInDollarsAndCents()
  {
    return priceInDollarsAndCents;
  }


  /**
    * This is returns the trade name of a Snack
    * @return the trade name of a Snack
    */ 
  public String getTradeName()
  {
    return tradeName;
  }

  /**
    * This compares two Snacks based on their tradeNames 
    * It returns 0 if the two Snacks have the same tradeName
    * and non-0, otherwise. 
    * @return  0 if the ingredients are the same, non-0 otherwise
    */
  public int compareTo(Object anotherSnack)
  {
    return (tradeName.compareTo(((Snack)anotherSnack).tradeName));
  }


  /**
    * Returns a String representation of a Snack including the
    * tradeName, ingredients and priceInDollarsAndCents
    * @return a String containing a representation of the Tree
    */
  public String toString()
  {
    String description = "";

    description = description + tradeName + ":" + eol;

    description = description +
           "     Price: $" + priceInDollarsAndCents + eol;

    description =  description + 
                   "     Ingredients:";
 
    for (int ingredientIndex=0; ingredientIndex<ingredients.size();
         ingredientIndex++)
    {
      description = description + 
                    " " + ingredients.elementAt(ingredientIndex);
      if ( (ingredientIndex+1) < ingredients.size())
        description += ",";
    }

    description += eol;
    return description;
  }

  // Ignore this. It just defines the end-of-line character
  private static String eol = System.getProperty ("line.separator");
}
