import java.io.*;
import java.util.*;

public class SnackMachine
{
  private LinkedList inventory;

   /**
   *  The constructor. It creates an inventory of Snacks
   *  from a file. You do not need to be concerned with 
   *  its implementation.
   *  @String fileName: the name of the data file containing the 
   *  description of the Snacks in the InventoryOfSnacks.
   */
  public SnackMachine(String fileName)
  {
    // The now familiar properties of a Snack
    Vector ingredients;
    String tradeName;
    double priceInDollarsAndCents;

    // Create the LinkedList to hold the inventory of Trees
    inventory = new LinkedList();

    try {

      // Open the file and prepare for reading
      File dataFile = new File (fileName);
      BufferedReader fileData = new 
      BufferedReader(new InputStreamReader (new FileInputStream(dataFile)));

      // Read each entry, creating a new tree. 
      // Stops when it can't get a description line
      String snackDescription; // One line from the data file
      while (null != (snackDescription = fileData.readLine()))
      {
        // Used to break down a line of the data file
        StringTokenizer snackDescriptionTokenizer; // Breaks down the line
        Vector snackDescriptionTokens = new Vector(); // Ind. parts of line

        // Break it into the individual descriptors
        snackDescriptionTokenizer = 
            new StringTokenizer (snackDescription, ",");

        // Break out each of the properties into its own String
        while (snackDescriptionTokenizer.hasMoreTokens())
          snackDescriptionTokens.add (snackDescriptionTokenizer.nextToken());

        // Grab the Snack's trade name
        tradeName = (String) snackDescriptionTokens.elementAt(0);
        snackDescriptionTokens.removeElementAt(0);

        // Grab the Snack's priceInDollarsAndCents
        priceInDollarsAndCents = 
            Double.parseDouble ((String)snackDescriptionTokens.elementAt(0));
        snackDescriptionTokens.removeElementAt(0);

        // What is left is a Vector of ingredients
        ingredients = snackDescriptionTokens;
  
        // Create the new Snack and add it to the machine's inventory
        inventory.addFirst (new Snack (tradeName, ingredients, 
                                       priceInDollarsAndCents)); 
      }
    }
    catch (EOFException eof)
    {
      // Don't worry -- we're done
    }
    catch (Exception e)
    {
      // This is a real problem
      System.out.println ("Problem reading input file: " +
                           e.toString());
      System.exit (1);
    }
  } 

  /**
    * This is the test program. It takes one parameter: the datafile
    * It will create a SnackMachine from the supplied inventory file 
    * and then allow the user to grab all of his favorite Snacks,
    *
    * For example: java SnackMachine datafiles/inventory1.dat 
    *
    * @args[1] is the name of the inventory file, including a path, 
    * if necessary
    */ 
  public static void main (String[] args)
  {
    SnackMachine snacks= new SnackMachine (args[0]);
    String tradeName;

    // Get the requested trade name
    tradeName = args[1];
    
    // Print out the initial inventory
    System.out.println ("The following is the initial list of available Snacks:");
    System.out.println ("");
    System.out.println (snacks.inventory);
    System.out.println ("");

    // Create the reference version of the favorite snack
    Snack favoriteSnack = new Snack (tradeName, new Vector(), 0.00);
    
    // Talk about grabbing the snacks from the machine
    System.out.print ("Grabbing all snacks with the following trade name: ");
    System.out.println (tradeName);
    System.out.println ("");

    // Actually remove the snacks from inventory
    snacks.inventory.removeAll(favoriteSnack);
    
    // Print out the inventory after removing our favorites
    System.out.println ("The following is the resulting list of available Snacks:");
    System.out.println ("");
    System.out.println (snacks.inventory);
    System.out.println ("");
  }
}
